import config from './config';

import QQMapWX from '@/common/js/qqmap-wx-jssdk.js';
const qqmapsdk = new QQMapWX({ key: config.QQMAPKEY });

const methods = {
  qqmapsdk,

  /**
   * 路由跳转
   * @param {object} params 参数
   * @param {string} params.path 页面名称
   * @param {string} params.pathPrefix 路径前缀，默认为 pages
   */
  wjRouterPush(params) {
    if (typeof params == 'object' && 'path' in params) {
      params.pathPrefix = params.pathPrefix || 'pages';
      uni.navigateTo({
        url: '/' + params.pathPrefix + '/' + params.path + '/view?' + methods.param(params.query),
      });
    } else {
      uni.navigateTo({
        url: '/pages/' + params + '/view',
      });
    }
  },

  wjRouterReplace(params) {
    if (typeof params == 'object' && 'path' in params) {
      params.pathPrefix = params.pathPrefix || 'pages';
      uni.redirectTo({
        url: '/' + params.pathPrefix + '/' + params.path + '/view?' + methods.param(params.query),
      });
    } else {
      uni.redirectTo({
        url: '/pages/' + params + '/view',
      });
    }
  },

  wjRouterSwitchTab(params) {
    uni.switchTab({
      url: '/pages/' + params + '/view',
    });
  },

  wjRouterGo(number = 1) {
    uni.navigateBack({
      delta: number,
    });
  },

  wjRequest(api, method, data, cb) {
    // 店铺ID
    data.shop_id = config.SHOPID;

    // 删除空参数
    for (let key in data) {
      if (this.isEmpty(data[key])) delete data[key];
    }

    // 附加 token
    let header = { 'Content-Type': 'application/json' };
    var token = uni.getStorageSync('token');
    if (token) header['authorization'] = 'Bearer ' + token;

    uni.request({
      url: config.APIURL + api,
      method,
      data,
      header,
      success: res => {
        cb(res.data);
      },
    });
  },

  // 更新用户信息
  getUser(cb = () => {}) {
    let token = uni.getStorageSync('token');
    if (methods.isEmpty(token)) return;
    methods.wjRequest('/user/profile', 'get', {}, res => {
      if (res.success) uni.setStorageSync('userInfo', res.data);
      else uni.clearStorageSync();
      cb(res);
    });
  },

  isEmpty(str) {
    if (str == '' || str == null || str == undefined || JSON.stringify(str) == '[]' || JSON.stringify(str) == '{}') {
      return true;
    } else {
      return false;
    }
  },

  logout() {
    localStorage.clear();
    uni.navigateTo({
      url: '/pages/login/view',
    });
  },

  removeEmptyArrayEle(arr) {
    var temArr = [];
    for (var i = 0; i < arr.length; i++) {
      if (!this.isEmpty(arr[i])) {
        temArr.push(arr[i]);
      }
    }
    return temArr;
  },

  // 元素是否在数组中
  in_array(search, array) {
    for (var i in array) {
      if (array[i] == search) {
        return true;
      }
    }
    return false;
  },

  // 深拷贝
  deepCopy(obj) {
    let objClone = Array.isArray(obj) ? [] : {};
    if (obj && typeof obj === 'object') {
      for (var key in obj) {
        if (obj.hasOwnProperty(key)) {
          //判断ojb子元素是否为对象，如果是，递归复制
          if (obj[key] && typeof obj[key] === 'object') {
            objClone[key] = this.deepCopy(obj[key]);
          } else {
            //如果不是，简单复制
            objClone[key] = obj[key];
          }
        }
      }
    }
    return objClone;
  },

  // 生成唯一jstoken
  jsGuid() {
    // Generate four random hex digits.
    function S4() {
      return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1);
    }
    // Generate a pseudo-GUID by concatenating random hexadecimal.
    function guid() {
      return S4() + S4() + '-' + S4() + '-' + S4() + '-' + S4();
    }
    return guid();
  },

  // 隐藏部分内容以星号*代替
  filterInfo(str, start, end, isEmail = false) {
    if (isEmail) {
      var em = str.split('@');
      str = em[0];
    }
    var s = str.substr(0, start);
    var e = str.substr(str.length - end, str.length - 1);
    var d = '*******************************'.substr(0, str.length - start - end);
    if (isEmail) {
      return s + d + e + '@' + em[1];
    }
    return s + d + e;
  },

  // 判断字符串是否是JSON
  isJSON(str) {
    if (typeof str == 'string') {
      try {
        var obj = JSON.parse(str);
        if (typeof obj == 'object' && obj) {
          return true;
        } else {
          return false;
        }
      } catch (e) {
        return false;
      }
    }
  },

  // json to queryString
  cleanArray(actual) {
    const newArray = [];
    for (let i = 0; i < actual.length; i++) {
      if (actual[i]) {
        newArray.push(actual[i]);
      }
    }
    return newArray;
  },

  param(json) {
    if (!json) return '';
    return this.cleanArray(
      Object.keys(json).map(key => {
        if (json[key] === undefined) return '';
        return encodeURIComponent(key) + '=' + encodeURIComponent(json[key]);
      })
    ).join('&');
  },

  // 格式化金额
  toMoney(num) {
    if (this.isEmpty(num)) return 0;
    num = num * 100;
    num = parseInt(num);
    num = num / 100;
    return num.toFixed(2);
  },

  // 拨打电话
  callPhone(e) {
    if (!this.isEmpty(e)) {
      uni.makePhoneCall({
        phoneNumber: e,
      });
    }
  },

  // 获取基础配置信息
  getSetting() {
    return new Promise(r => {
      this.wjRequest('/setting', 'get', {}, res => {
        r(res.data);
      });
    });
  },

  // 小于10补0
  autoZore(num) {
    if (num < 10) {
      return '0' + num.toString();
    } else {
      return num.toString();
    }
  },

  /*
   * 查询字符串转换为JSON格式
   * @param {String} str 查询字符串
   */
  queryStringToJSON(str, queryString) {
    var t = new RegExp('(^|&)' + str + '=([^&]*)(&|$)');
    try {
      var n = queryString.match(t);
    } catch (r) {
      return null;
    }
    return n != null ? n[2] : null;
  },

  // 自动补充 0
  PrefixInteger(num, length) {
    return (Array(length).join('0') + num).slice(-length);
  },

  getLocation(cb) {
    uni.getLocation({
      type: 'gcj02',
      success: res => {
        let userLocation = {
          longitude: res.longitude,
          latitude: res.latitude,
        };
        this.reverseGeocoder(userLocation, res => {
          cb(res);
        });
      },
    });
  },

  /**
   * 根据经纬度转换为地址
   * @param {*} latlng 经纬度
   * {
   *   longitude: res.longitude,
   *   latitude: res.latitude,
   * }
   */
  reverseGeocoder(latlng, cb) {
    qqmapsdk.reverseGeocoder({
      location: latlng,
      success: res2 => {
        console.log(res2);
        latlng.address_component = res2.result.address_component;
        latlng.address_component.provinceCode = res2.result.ad_info.adcode.substring(0, 2) + '0000';
        latlng.address_component.cityCode = res2.result.ad_info.adcode.substring(0, 4) + '00';
        latlng.address_component.districtCode = res2.result.ad_info.adcode;
        latlng.address = res2.result.address;
        uni.setStorageSync('userLocation', latlng);
        cb(latlng);
      },
      fail: err => {
        console.log('经纬度转换地址失败', err);
      },
    });
  },

  getCart(cb) {
    let userInfo = uni.getStorageSync('userInfo');
    if (methods.isEmpty(userInfo)) return;

    this.wjRequest('/cart', 'post', {}, res => {
      cb(res.data);
    });
  },

  getDistance(lng1, lat1, lng2, lat2) {
    const radLat1 = (lat1 * Math.PI) / 180.0;
    const radLat2 = (lat2 * Math.PI) / 180.0;
    const a = radLat1 - radLat2;
    const b = (lng1 * Math.PI) / 180.0 - (lng2 * Math.PI) / 180.0;
    let s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) + Math.cos(radLat1) * Math.cos(radLat2) * Math.pow(Math.sin(b / 2), 2)));
    s = s * 6378.137; // EARTH_RADIUS;
    s = Math.round(s * 10000) / 10000;
    return s;
  },

  copyText(data) {
    uni.setClipboardData({
      data,
      success: function () {
        console.log('copy success');
      },
    });
  },
};

export default methods;
