export default {
  data() {
    return {
      selectAddress: {},
      checkIds: [],
      dataList: [],
      goodsPrice: 0,
      goodsNumber: 0,
      remark: '',
      setting: {},
      addressCanBuy: true,
      freightPrice: 0,
      price: 0,
      delivery_type: 'express',
      delivery_type_index: 0,
      delivery_type_array: [
        { label: '配送', value: 'horseman' },
        { label: '自提', value: 'self' },
      ],
      freightObj: {},
      cfmOpts: {
        show: false,
        content: '',
        showCancel: false,
      },
      canOrderBuy: true,
    };
  },

  async onShow() {
    let selectAddress = uni.getStorageSync('selectAddress') || {};
    if (!this.isEmpty(selectAddress)) {
      uni.removeStorageSync('selectAddress');
      this.selectAddress = selectAddress;
      this.calePrice();
    }
  },

  async onLoad() {
    this.checkIds = uni.getStorageSync('checkIds');
    await this.getAddress();
    this.setting = await this.getSetting();
    if (!this.isEmpty(this.setting.freightOption.deliveryType.express)) this.delivery_type = 'express';
    if (!this.isEmpty(this.setting.freightOption.deliveryType.horseman)) this.delivery_type = 'horseman';
    this.getCart();
  },

  methods: {
    getCheckOrder() {
      return new Promise(r => {
        this.wjRequest(
          '/order/checkOrder',
          'post',
          {
            ids: this.checkIds,
            address_id: this.selectAddress.id,
            remark: this.remark,
            delivery_type: this.delivery_type,
          },
          res => {
            if (res.success) {
              r({ ...res.data, addressCanBuy: true });
            } else {
              this.cfmOpts.content = res.message;
              this.cfmOpts.show = true;
              this.canOrderBuy = false;
              r({ addressCanBuy: false, freightPrice: 0 });
            }
          }
        );
      });
    },

    dtaClick(tindex) {
      this.delivery_type_index = tindex;
      this.delivery_type = this.delivery_type_array[tindex].value;
      if (tindex == 0) {
        this.freightPrice = this.freightObj.freightPrice;
        this.price = this.goodsPrice + this.freightPrice;
      } else {
        this.freightPrice = 0;
        this.price = this.goodsPrice;
      }
    },

    getAddress() {
      return new Promise(r => {
        this.wjRequest('/address', 'get', { rows: 1 }, res => {
          if (!this.isEmpty(res.data)) {
            if (res.data[0].default) {
              this.selectAddress = res.data[0];
            }
          }
          r();
        });
      });
    },

    getCart() {
      this.wjRequest('/cart', 'post', { include: this.checkIds }, res => {
        this.dataList = res.data;
        this.calePrice();
      });
    },

    async calePrice() {
      this.price = 0;
      this.goodsPrice = 0;
      this.goodsNumber = 0;

      let price = 0;
      for (let i = 0; i < this.dataList.length; i++) {
        this.goodsPrice += this.dataList[i].sku.goods_price * this.dataList[i].buy_number;
        this.goodsNumber += this.dataList[i].buy_number;
      }
      price = this.goodsPrice;

      if (!this.isEmpty(this.selectAddress)) {
        this.freightObj = await this.getCheckOrder();
        this.freightPrice = this.freightObj.freightPrice;
        await this.$nextTick();
        this.addressCanBuy = this.freightObj.addressCanBuy;
        price += this.freightPrice;
      }

      this.price = price;
    },

    submitForm() {
      if (this.isEmpty(this.selectAddress)) {
        uni.showToast({ title: '请选择收货地址', icon: 'none' });
        return;
      }

      this.wjRequest(
        '/order/add',
        'post',
        {
          ids: this.checkIds,
          address_id: this.selectAddress.id,
          remark: this.remark,
          delivery_type: this.delivery_type,
        },
        res => {
          if (res.success) {
            this.wjRouterReplace({
              path: 'checkOut',
              query: {
                order_id: res.data.order_id,
                order_no: res.data.order_no,
              },
            });
          } else {
            uni.showToast({ title: res.message, icon: 'none' });
          }
        }
      );
    },

    toSelectA() {
      if (this.delivery_type == 'self') {
        // 查看商家位置
        uni.openLocation({
          latitude: Number(this.setting.shop.latitude),
          longitude: Number(this.setting.shop.longitude),
          name: this.setting.shop.name,
          address: this.setting.shop.fullAddress,
          fail: err => {
            console.log(err);
          },
        });
      } else {
        this.wjRouterPush({ path: 'address', query: { type: 'select' } });
      }
    },
  },
};
