import { mapState } from 'vuex';

export default {
  data() {
    return {
      svTop: 0,
      addCartShow: false,
      goods: {},
      defaultSku: {
        sku_code: '',
        goods_price: '',
        market_price: '',
        goods_stock: '',
        merchant_code: '',
        buy_number: 1,
      },
      needAuth: false,
    };
  },

  onLoad() {
    this.getGoodsSingle();
  },

  onShow() {
    this.updateCartView();
  },

  computed: mapState({
    cartNum: state => state.cartNum,
  }),

  methods: {
    updateCartView() {
      this.getCart(data => {
        if (data) {
          this.$store.commit('updateCartNum', data.length);
          if (data.length) uni.setTabBarBadge({ index: 2, text: String(data.length) });
          else uni.removeTabBarBadge({ index: 2 });
        } else {
          uni.removeTabBarBadge({ index: 2 });
        }
      });
    },

    getGoodsSingle() {
      this.wjRequest('/post/' + this.pageParams.id, 'get', {}, res => {
        this.goods = res.data;
        this.initSku();
      });
    },

    initSku() {
      this.defaultSku.sku_code = '';
      this.defaultSku.goods_price = this.goods.goods_price;
      this.defaultSku.market_price = this.goods.market_price;
      this.defaultSku.goods_stock = this.goods.goods_stock;
      this.defaultSku.merchant_code = this.goods.merchant_code;
      this.defaultSku.buy_number = 1;
    },

    skuClick(sitem, sindex, citem, cindex) {
      this.goods.saleAttrNames[sindex].children.map((item, index) => {
        if (index == cindex) item.check = !item.check;
        else item.check = false;
      });
      this.$forceUpdate();
      this.calcPrice();
    },

    calcPrice() {
      let selectSku = [];
      let selectSkuKey = [];
      for (let i = 0; i < this.goods.saleAttrNames.length; i++) {
        for (let j = 0; j < this.goods.saleAttrNames[i].children.length; j++) {
          this.goods.saleAttrNames[i].children[j].category_name = this.goods.saleAttrNames[i].category_name;
          if (this.goods.saleAttrNames[i].children[j].check) {
            selectSkuKey[i] = this.PrefixInteger(this.goods.saleAttrNames[i].children[j].id, 3);
            selectSku[i] = this.goods.saleAttrNames[i].children[j];
          }
        }
      }

      // 删除空元素
      selectSku = selectSku.filter(n => {
        return n;
      });
      selectSkuKey = selectSkuKey.filter(n => {
        return n;
      });

      if (this.isEmpty(selectSkuKey)) {
        this.initSku();
        return;
      }

      for (let i = 0; i < this.goods.disposeSkuGroup.length; i++) {
        if (this.goods.disposeSkuGroup[i].sku_code == selectSkuKey.join('-')) {
          this.defaultSku = { ...this.goods.disposeSkuGroup[i], buy_number: 1, select: selectSku };
          break;
        }
      }
    },

    changeBuyNumber(e) {
      if (e == -1) {
        if (this.defaultSku.buy_number > 1) this.defaultSku.buy_number--;
      } else {
        if (this.defaultSku.buy_number < this.defaultSku.goods_stock) this.defaultSku.buy_number++;
      }
    },

    addCart() {
      if (this.isEmpty(this.userInfo)) {
        this.needAuth = true;
        return;
      }

      if (!this.isEmpty(this.goods.saleAttrNames) && this.isEmpty(this.defaultSku.sku_code)) {
        uni.showToast({ title: '请选择规格', icon: 'none' });
        return;
      }

      this.wjRequest('/cart/add', 'post', { goods_id: this.pageParams.id, sku: this.defaultSku }, res => {
        uni.showToast({ title: res.message, icon: 'none' });
        if (res.success) {
          this.addCartShow = false;
          this.updateCartView();
        }
      });
    },

    logged(userInfo) {
      this.userInfo = userInfo;
      this.needAuth = false;
    },

    toBanner(bitem) {
      uni.previewImage({
        urls: this.goods.thumbnail,
        current: bitem,
      });
    },
  },
};
