import orderMixins from '@/mixins/order-mixins.js';

export default {
  mixins: [orderMixins],
  data() {
    return {
      order_status: {
        all: '全部',
        unpaid: '待付款',
        paid: '待发货',
        delivery: '待收货',
        finished: '已完成',
        cancel: '已取消',
      },
      tabKey: 'all',

      dataList: [],
      page: 0,
      rows: 20,
      isLoading: false,
      noMore: false,
      svHeight: 0,
    };
  },
  onLoad() {
    let wInfo = uni.getSystemInfoSync();
    this.svHeight = wInfo.windowHeight - (wInfo.windowWidth / 750) * 80 - 1;

    this.tabKey = this.pageParams.type;
    this.getData();
  },
  methods: {
    tabClick(key) {
      this.tabKey = key;
      this.page = 0;
      this.noMore = false;
      this.getData();
    },

    getData() {
      if (this.isLoading) return;
      if (this.noMore) return;
      uni.showLoading({ title: '加载中' });
      this.page++;
      this.wjRequest(
        '/order',
        'get',
        {
          page: this.page,
          rows: this.rows,
          status: this.tabKey == 'all' ? null : this.tabKey,
        },
        res => {
          uni.hideLoading();
          if (res.data.length < this.rows) this.noMore = true;
          if (this.page) this.dataList = res.data;
          else this.dataList.push(...res.data);
        }
      );
    },
  },
};
