import orderMixins from '@/mixins/order-mixins.js';

export default {
  mixins: [orderMixins],
  data() {
    return {
      order: {},
      order_status: {
        all: '全部',
        unpaid: '待付款',
        paid: '待发货',
        delivery: '待发货',
        finished: '已完成',
        cancel: '已取消',
      },
      setting: {},
      timeCount: [],
      serverDate: '',
      orderDate: '',
      promoter: { user: '用户', shop: '商家' },
      refundStatus: { pending: '发起退款', progress: '退款中', finished: '已完成' },
      refundAmountAll: 0,
    };
  },

  onLoad() {
    this.getOrder();
    uni.$on('timer', this.orderTimeOut);
    this.getSetting().then(data => {
      this.setting = data;
    });
  },

  methods: {
    getOrder() {
      this.wjRequest('/order/single', 'get', { id: this.pageParams.id }, res => {
        if (res.success) {
          this.order = res.data;
          this.serverDate = new Date(res.serverDate).getTime();
          this.orderDate = new Date(res.data.create_date).getTime();
          // 计算总退款金额
          if (!this.isEmpty(this.order.refund)) {
            for (let i = 0; i < this.order.refund.length; i++) {
              this.refundAmountAll += Number(this.order.refund[i].refund_money);
            }
          }
        } else {
          uni.showToast({ title: res.message, none: 'icon' });
        }
      });
    },

    orderTimeOut() {
      if (this.isEmpty(this.order)) return;
      if (this.isEmpty(this.setting.orderOption)) return;
      this.serverDate += 1000;
      let cancelTime = 0;
      if (this.order.status == 'unpaid') cancelTime = this.orderDate + this.setting.orderOption.unpaidCancelTime * 60 * 1000;
      else if (this.order.status == 'delivery') cancelTime = this.orderDate + this.setting.orderOption.shippedConfirmTime * 60 * 60 * 1000;
      let lessTime = cancelTime - this.serverDate;
      if (lessTime <= 0) {
        this.timeCount = [];
        return;
      }

      // 格式化为倒计时 时分秒
      let h = Math.floor(lessTime / (60 * 60 * 1000));
      let m = Math.floor((lessTime - h * 60 * 60 * 1000) / (60 * 1000));
      let s = Math.floor((lessTime / 1000) % 60);
      this.timeCount = [this.autoZore(h), this.autoZore(m), this.autoZore(s)];
    },
  },

  onUnload() {
    uni.$off('timer', this.orderTimeOut);
  },
};
